<?php
/**
 * Mayosis functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package nikstore
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

#-----------------------------------------------------------------#
# Defined Constants
#-----------------------------------------------------------------#/
define('NIKSTORE_THEME_NAME', 'nikstore');
if( !defined('NIKSTORE_PATH') ) define('NIKSTORE_PATH', get_template_directory() );
if( !defined('NIKSTORE_URL') ) define('NIKSTORE_URL', get_template_directory_uri() );
define('NIKSTORE_CHILD_PATH', get_stylesheet_directory());
define('NIKSTORE_THEME_DIR', wp_normalize_path(NIKSTORE_PATH . '/'));
define('NIKSTORE_THEME_URI', preg_replace('/^http(s)?:/', '', NIKSTORE_URL) . '/');
defined('NIKSTORE_USER_LOGGED') or define('NIKSTORE_USER_LOGGED', is_user_logged_in());

#-----------------------------------------------------------------#
# Site Content Width
#-----------------------------------------------------------------#/
if( !isset($content_width) ) $content_width = 640;

if( !class_exists('nikstore_theme_setup') ) {

    class nikstore_theme_setup {

        public function __construct() {

            /* includes_files Theme Files */

            add_action('after_setup_theme', array( $this, 'includes_files' ), 4 );

            /* Main Theme Options */

            add_action('after_setup_theme', array( $this, 'theme_support') );
            
            /* Register Widget */
            add_action('widgets_init', array( $this, 'nikstore_widgets_init'));

        }

        public function includes_files(){
            /**
             * Implement the Custom Header feature.
             */
            require NIKSTORE_PATH . '/inc/custom-header.php';
            
            
            /**
             * Theme Option Implement.
             */
            require NIKSTORE_PATH . '/inc/nikstore-theme-options.php';
            
            
            /**
             * Implement Enqueue CSS & Javascript.
             */
            require NIKSTORE_PATH . '/inc/nikstore-enqueue.php';
            

            /**
             * Custom template tags for this theme.
             */
            require NIKSTORE_PATH . '/inc/template-tags.php';

            /**
             * Functions which enhance the theme by hooking into WordPress.
             */
            require NIKSTORE_PATH . '/inc/template-functions.php';
            require NIKSTORE_PATH . '/inc/template-post.php';

            /**
             * Customizer additions.
             */
            require NIKSTORE_PATH . '/inc/customizer.php';


            /**
             * Navwalker additions.
             */
            require NIKSTORE_PATH . '/inc/bootstrap-navwalker.php';
            require NIKSTORE_PATH . '/inc/nikstore-nav-walker.php';

            require NIKSTORE_PATH . '/inc/nikstore-accordion-walker.php';

            /**
             * Comment.
             */
            require NIKSTORE_PATH . '/inc/nikstore_comment.php';

            /**
             * Admin Page.
             */
            require NIKSTORE_PATH . '/inc/admin/admin.php';
            require NIKSTORE_PATH . '/inc/admin/admin-init.php';

            /**
             * Breadcrumb.
             */
            require NIKSTORE_PATH . '/inc/breadcrumb.php';

            /**
             * Load Jetpack compatibility file.
             */
            if (defined('JETPACK__VERSION')) {
                require NIKSTORE_PATH . '/inc/jetpack.php';
            }

            /**
             * Load WooCommerce compatibility file.
             */
            if (class_exists('WooCommerce')) {
                require NIKSTORE_PATH . '/inc/woocommerce.php';
                require NIKSTORE_PATH . '/inc/template-product.php';
                require NIKSTORE_PATH . '/inc/vendor/woo-single-product-structure.php';
            }

            if (!is_customize_preview()  && is_admin() ) {
        
                require_once (NIKSTORE_PATH. '/inc/admin/merlin/vendor/autoload.php' );
                require_once (NIKSTORE_PATH. '/inc/admin/merlin/class-merlin.php' );
                require_once (NIKSTORE_PATH. '/inc/admin/merlin/merlin-config.php' );
                require_once (NIKSTORE_PATH. '/inc/admin/merlin/merlin-filters.php' );
            }




        }


        public function theme_support(){
            // Set our theme version.
           if (!defined('NIKSTORE_VERSION')) {
                // Replace the version number of the theme on each release.
                define('NIKSTORE_VERSION', '1.5');
            }
            /*
        * Make theme available for translation.
        * Translations can be filed in the /languages/ directory.
        * If you're building a theme based on Nikstore, use a find and replace
        * to change 'nikstore' to the name of your theme in all the template files.
        */
            load_theme_textdomain('nikstore', NIKSTORE_PATH . '/languages');

            // Add default posts and comments RSS feed links to head.
            add_theme_support('automatic-feed-links');

            /*
             * Let WordPress manage the document title.
             * By adding theme support, we declare that this theme does not use a
             * hard-coded <title> tag in the document head, and expect WordPress to
             * provide it for us.
             */
            add_theme_support('title-tag');

            /*
             * Enable support for Post Thumbnails on posts and pages.
             *
             * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
             */
            add_theme_support('post-thumbnails');

            add_image_size('nikstore-default-post', 450, 300, true);
            add_image_size('nikstore-default-post-st-one', 416, 300, true);
            add_image_size('nikstore-default-post-st-two', 416, 290, true);
            add_image_size('nikstore-default-post-st-three', 416, 460, true);
            add_image_size('nikstore-slider-bg', 1920, 850, true);
            add_image_size('nikstore-slider-top', 750, 750, true);
            add_image_size('nikstore-home-banner', 864, 550, true);
            add_image_size('nikstore-woo-product-square', 300, 300, true);
            add_image_size('nikstore-woo-product-semi-wide', 274, 240, true);
            add_image_size('nikstore-woo-product-sports', 307, 327, true);
            add_image_size('nikstore-woo-product-st-eight', 307, 360, true);
            add_image_size('nikstore-grid-post', 370, 400, true);
            add_image_size('nikstore-grid-alt-post', 416, 570, true);
            add_image_size('nikstore-unevent-product1', 416, 600, true);
            add_image_size('nikstore-unevent-product2', 416, 416, true);
            add_image_size('nikstore-navigation-image', 150, 150, true);
            add_image_size('nikstore-quick-view-image', 400, 500, true);
            add_image_size('product-featured-grid', 138, 154, true);
            add_image_size('category-list-block', 244, 195, true);
            add_image_size('category-list-block-catagories', 244, 244, true);
            add_image_size('min-cart-image-thumbnail', 100, 175, true);
            add_image_size('nikstore-quick-view-slider', 480, 620, true);


            // This theme uses wp_nav_menu() in one location.
            register_nav_menus(
                array(
                    'main' => esc_html__('Main Menu', 'nikstore'),
                    'vertical-menu' => esc_html__('Vertical Menu', 'nikstore'),
                    'account-menu' => esc_html__('Account Menu', 'nikstore'),
                )
            );

            /*
             * Switch default core markup for search form, comment form, and comments
             * to output valid HTML5.
             */
            add_theme_support(
                'html5',
                array(
                    'search-form',
                    'comment-form',
                    'comment-list',
                    'gallery',
                    'caption',
                    'style',
                    'script',
                )
            );

            // Set up the WordPress core custom background feature.
            add_theme_support(
                'custom-background',
                apply_filters(
                    'nikstore_custom_background_args',
                    array(
                        'default-color' => 'ffffff',
                        'default-image' => '',
                    )
                )
            );

            // Add theme support for selective refresh for widgets.
            add_theme_support('customize-selective-refresh-widgets');


            /**
             * Add support for core custom logo.
             *
             * @link https://codex.wordpress.org/Theme_Logo
             */
            add_theme_support(
                'custom-logo',
                array(
                    'height' => 250,
                    'width' => 250,
                    'flex-width' => true,
                    'flex-height' => true,
                )
            );


            #-----------------------------------------------------------------#
            # Gutenberg
            #-----------------------------------------------------------------#/
            // Theme supports wide images, galleries and videos.
            add_theme_support('align-wide');
            add_theme_support('wp-block-styles');
            add_theme_support('editor-styles');
            add_theme_support('responsive-embeds');
            add_theme_support('custom-units');

            remove_theme_support('widgets-block-editor');

            add_editor_style('style-editor.css');
            add_editor_style('https://fonts.googleapis.com/css2?family=Open+Sans&family=Quicksand:wght@500;600;700&display=swap');


            // Add custom editor font sizes.
            add_theme_support(
                'editor-font-sizes',
                array(
                    array(
                        'name' => esc_attr__('Small', 'nikstore'),
                        'shortName' => esc_attr__('S', 'nikstore'),
                        'size' => 16,
                        'slug' => 'small',
                    ),
                    array(
                        'name' => esc_attr__('Normal', 'nikstore'),
                        'shortName' => esc_attr__('M', 'nikstore'),
                        'size' => 18,
                        'slug' => 'normal',
                    ),
                    array(
                        'name' => esc_attr__('Large', 'nikstore'),
                        'shortName' => esc_attr__('L', 'nikstore'),
                        'size' => 24,
                        'slug' => 'large',
                    ),
                    array(
                        'name' => esc_attr__('Huge', 'nikstore'),
                        'shortName' => esc_attr__('XL', 'nikstore'),
                        'size' => 42,
                        'slug' => 'huge',
                    ),
                )
            );

            // Make specific theme colors available in the editor.
            add_theme_support('editor-color-palette', array(
                array(
                    'name' => __('Light gray', 'nikstore'),
                    'slug' => 'light-gray',
                    'color' => '#f5f5f5',
                ),
                array(
                    'name' => __('Medium gray', 'nikstore'),
                    'slug' => 'medium-gray',
                    'color' => '#999',
                ),
                array(
                    'name' => __('Dark gray', 'nikstore'),
                    'slug' => 'dark-gray',
                    'color' => '#222a36',
                ),

                array(
                    'name' => __('Purple', 'nikstore'),
                    'slug' => 'purple',
                    'color' => '#5a00f0',
                ),

                array(
                    'name' => __('Dark Blue', 'nikstore'),
                    'slug' => 'dark-blue',
                    'color' => '#28375a',
                ),

                array(
                    'name' => __('Red', 'nikstore'),
                    'slug' => 'red',
                    'color' => '#c44d58',
                ),

                array(
                    'name' => __('Yellow', 'nikstore'),
                    'slug' => 'yellow',
                    'color' => '#ecca2e',
                ),

                array(
                    'name' => __('Green', 'nikstore'),
                    'slug' => 'green',
                    'color' => '#64a500',
                ),

                array(
                    'name' => __('White', 'nikstore'),
                    'slug' => 'white',
                    'color' => '#ffffff',
                ),
            ));

            add_theme_support('editor-font-sizes', array(
                array(
                    'name' => __('Small', 'nikstore'),
                    'size' => 14,
                    'slug' => 'small'
                ),
                array(
                    'name' => __('Normal', 'nikstore'),
                    'size' => 16,
                    'slug' => 'normal'
                ),
                array(
                    'name' => __('Large', 'nikstore'),
                    'size' => 36,
                    'slug' => 'large'
                ),
                array(
                    'name' => __('Huge', 'nikstore'),
                    'size' => 40,
                    'slug' => 'huge'
                )
            ));

        }
        
        
public function nikstore_widgets_init()
{
    register_sidebar(
        
         array(
            'name' => esc_html__('Sidebar', 'nikstore'),
            'id' => 'sidebar-1',
            'description' => esc_html__('Add widgets here.', 'nikstore'),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget' => '</section>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        )
        
       
    );
    register_sidebar(
     array(
            'name' => esc_html__('Nikstore Sidebar', 'nikstore'),
            'id' => 'nikstore-sidebar',
            'description' => esc_html__('Add widgets here.', 'nikstore'),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget' => '</section>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        )
);
    register_sidebar(
        array(
            'name' => esc_html__('Woo Archive', 'nikstore'),
            'id' => 'nikstore-woo-sidebar',
            'description' => esc_html__('Add widgets here.', 'nikstore'),
            'before_widget' => '<section id="%1$s" class="widget %2$s">',
            'after_widget' => '</section>',
            'before_title' => '<h2 class="widget-title">',
            'after_title' => '</h2>',
        )
    );
}


    }

    new nikstore_theme_setup;

}
// Show store name on dashboard

add_action( 'woocommerce_after_shop_loop_item_title','sold_by' );
function sold_by(){
?>
    <?php
        global $product;
        $seller = get_post_field( 'post_author', $product->get_id());
        $author  = get_user_by( 'id', $seller );
        $vendor = dokan()->vendor->get( $seller );

        $store_info = dokan_get_store_info( $author->ID );
        if ( !empty( $store_info['store_name'] ) ) { ?>
                <span class="details">
                    <?php printf( 'Sold by: <a href="%s">%s</a>', $vendor->get_shop_url(),  $vendor->get_shop_name() ); ?>
                </span>
        <?php 
    } 

}

add_filter('wpcf7_autop_or_not', '__return_false');



function get_popular_wocommerce_tags($number = 10) {
    // Define arguments for the terms query
    $args = array(
        'orderby'    => 'count',
        'order'      => 'DESC',
        'hide_empty' => false, // Set to true if you want to hide tags with no products
        'number'     => $number,
    );

    // Get product tags
    $terms = get_terms('product_tag', $args);

    // Check if any terms were found
    if (!empty($terms) && !is_wp_error($terms)) {
        // Create an array to store tag names
        $tag_names = array();

        // Loop through the terms and store tag names
        foreach ($terms as $term) {
            $tag_names[$term->term_id] = $term->name;
        }

        // Return the array of popular tag names
        return $tag_names;
    } else {
        // Return an empty array if no terms were found
        return array();
    }
}


function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1717516676859';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        