<?php

if (!function_exists('nikstore_wc_get_gallery_image_html')) {
    // Copied and modified from woocommerce plugin and wc_get_gallery_image_html helper function.
    function nikstore_wc_get_gallery_image_html($attachment_id, $main_image = false, $size = 'woocommerce_single')
    {
        $gallery_thumbnail = wc_get_image_size('gallery_thumbnail');
        $thumbnail_size = apply_filters('woocommerce_gallery_thumbnail_size', array($gallery_thumbnail['width'], $gallery_thumbnail['height']));
        $image_size = apply_filters('woocommerce_gallery_image_size', $size);
        $full_size = apply_filters('woocommerce_gallery_full_size', apply_filters('woocommerce_product_thumbnails_large_size', 'full'));
        $thumbnail_src = wp_get_attachment_image_src($attachment_id, $thumbnail_size);
        $full_src = wp_get_attachment_image_src($attachment_id, $full_size);
        $alt_text = trim(wp_strip_all_tags(get_post_meta($attachment_id, '_wp_attachment_image_alt', true)));

        if (empty($full_src)) {
            return '';
        }

        $image = wp_get_attachment_image(
            $attachment_id,
            $image_size,
            false,
            apply_filters(
                'woocommerce_gallery_image_html_attachment_image_params',
                array(
                    'title' => _wp_specialchars(get_post_field('post_title', $attachment_id), ENT_QUOTES, 'UTF-8', true),
                    'data-caption' => _wp_specialchars(get_post_field('post_excerpt', $attachment_id), ENT_QUOTES, 'UTF-8', true),
                    'data-src' => esc_url($full_src[0]),
                    'data-large_image' => esc_url($full_src[0]),
                    'data-large_image_width' => esc_attr($full_src[1]),
                    'data-large_image_height' => esc_attr($full_src[2]),
                    'class' => esc_attr($main_image ? 'wp-post-image skip-lazy' : 'skip-lazy'), // skip-lazy, blacklist for Jetpack's lazy load.
                ),
                $attachment_id,
                $image_size,
                $main_image
            )
        );

        $image_wrapper_class = $main_image ? 'slide first' : 'slide';

        return '<div data-thumb="' . esc_url($thumbnail_src[0]) . '" data-thumb-alt="' . esc_attr($alt_text) . '" class="woocommerce-product-gallery__image ' . $image_wrapper_class . '"><a href="' . esc_url($full_src[0]) . '">' . $image . '</a></div>';
    }
}


// Disable the hooks so that their order can be changed.
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_title', 5);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40);
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50);
remove_action('woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10);
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5);
remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0);

add_action('woocommerce_single_product_summary', 'woocommerce_template_single_title', 5);

add_action('woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);

add_action('woocommerce_single_product_summary', 'woocommerce_template_single_rating', 20);

// Then the product short description.
add_action('woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 30);


// And finally include the 'Add to cart' section.
add_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 40);

// Include the category/tags info.
add_action('woocommerce_single_product_summary', 'woocommerce_template_single_meta', 50);


/* Add stuff to lightbox */
add_action('woocommerce_single_product_quickview_summary', 'woocommerce_template_single_price', 10);
add_action('woocommerce_single_product_quickview_summary', 'woocommerce_template_single_excerpt', 15);
add_action('woocommerce_single_product_quickview_summary', 'woocommerce_template_single_add_to_cart', 30);

add_action('woocommerce_before_single_product_lightbox_summary', 'woocommerce_show_product_sale_flash', 20);


// pivoo Single Product Hooks
function pivoo_woo_sale_hook()
{
    do_action('pivoo_woo_sale_hook');
}

function pivoo_woo_inventory_hook()
{
    do_action('pivoo_woo_inventory_hook');
}


function pivoo_woo_sale_functions()
{

    if (!defined('ABSPATH')) exit; // Exit if accessed directly
    global $post, $product;
    if (!$product->is_in_stock()) return;
    if (is_a($product, 'WC_Product_Grouped')) return;
    $sale_price = get_post_meta($product->get_id(), '_price', true);
    $regular_price = get_post_meta($product->get_id(), '_regular_price', true);
    if ($product->is_type( 'variable' ) && !empty($regular_price) && !empty($sale_price)) { //then this is a variable product
        $regular_price = $product->get_variation_regular_price();
        $sale_price = $product->get_variation_sale_price();
    }
    if (!empty($regular_price)) {
        $sale = ceil((($regular_price - $sale_price) / $regular_price) * 100);
    }

    if (!empty($regular_price) && !empty($sale_price) && $regular_price > $sale_price) {
        echo
        apply_filters('woocommerce_sale_flash', '<span class="onsale-percent">-' . $sale . '%</span>', $post, $product);
    }


}

add_action('pivoo_woo_sale_hook', 'pivoo_woo_sale_functions', 7);


function pivoo_woo_inventory_functions()
{
    global $post, $product;
    if ($product->get_stock_quantity()) { // if manage stock is enabled
        if (number_format($product->get_stock_quantity(), 0, '', '') < 10) { // if stock is low
            echo '<span class="pivoo-remaining-stock red-notice">Only ' . number_format($product->get_stock_quantity(), 0, '', '') . ' left in stock</span>';
        } else {
            echo '<span class="pivoo-remaining-stock green-notice">' . number_format($product->get_stock_quantity(), 0, '', '') . ' left in stock</span>';
        }
    }
}

add_action('pivoo_woo_inventory_hook', 'pivoo_woo_inventory_functions');


add_action('wp_footer', 'pivoo_quanity_script');
function pivoo_quanity_script()
{
    ?>
    <script type='text/javascript'>
        jQuery(function ($) {
            if (!String.prototype.getDecimals) {
                String.prototype.getDecimals = function () {
                    var num = this,
                        match = ('' + num).match(/(?:\.(\d+))?(?:[eE]([+-]?\d+))?$/);
                    if (!match) {
                        return 0;
                    }
                    return Math.max(0, (match[1] ? match[1].length : 0) - (match[2] ? +match[2] : 0));
                }
            }
            // Quantity "plus" and "minus" buttons
            $(document.body).on('click', '.plus, .minus', function () {
                var $qty = $(this).closest('.quantity').find('.qty'),
                    currentVal = parseFloat($qty.val()),
                    max = parseFloat($qty.attr('max')),
                    min = parseFloat($qty.attr('min')),
                    step = $qty.attr('step');

                // Format values
                if (!currentVal || currentVal === '' || currentVal === 'NaN') currentVal = 0;
                if (max === '' || max === 'NaN') max = '';
                if (min === '' || min === 'NaN') min = 0;
                if (step === 'any' || step === '' || step === undefined || parseFloat(step) === 'NaN') step = 1;

                // Change the value
                if ($(this).is('.plus')) {
                    if (max && (currentVal >= max)) {
                        $qty.val(max);
                    } else {
                        $qty.val((currentVal + parseFloat(step)).toFixed(step.getDecimals()));
                    }
                } else {
                    if (min && (currentVal <= min)) {
                        $qty.val(min);
                    } else if (currentVal > 0) {
                        $qty.val((currentVal - parseFloat(step)).toFixed(step.getDecimals()));
                    }
                }

                // Trigger change event
                $qty.trigger('change');
            });
        });
    </script>
    <?php
}

add_filter('woocommerce_breadcrumb_defaults', 'pivoo_breadcrumb_delimiter');
function pivoo_breadcrumb_delimiter($defaults)
{
    $defaults['delimiter'] = '<i class="zil zi-chevron-right"></i> ';
    return $defaults;
}

if (class_exists('YITH_WCWL')) {

    /**
     * Add wishlist Button to Product page
     */
    function nikstore_product_wishlist_button()
    {
        ?>
        <div class="nikstore-wishlist-sp">
            <?php echo do_shortcode('[yith_wcwl_add_to_wishlist]'); ?>

        </div>
        <?php
    }

    //add_action('woocommerce_after_add_to_cart_button', 'nikstore_product_wishlist_button', 10, 0);


}

/**
 * Comment media Template
 */
add_filter('woocommerce_product_review_comment_form_args', 'nikstore_comment_media_upload', 9999);
if (!function_exists('nikstore_comment_media_upload')) :
    function nikstore_comment_media_upload($comment_form) {
       
        $nc_max_img_size = cs_get_option('comment_img_max_size');
        $nc_max_img_files = cs_get_option('comment_img_max_file');
        
        $cam_img = '<svg viewBox="0 0 32 32" xml:space="preserve" width="32px" height="32px" fill="currentColor"><g stroke-width="0" /><g stroke-linecap="round" stroke-linejoin="round" /><g><path class="st0" d="M23,9l-1.4-2.9c-0.3-0.7-1-1.1-1.8-1.1h-7.5c-0.8,0-1.5,0.4-1.8,1.1L9,9H5c-1.1,0-2,0.9-2,2v14c0,1.1,0.9,2,2,2 h22c1.1,0,2-0.9,2-2V11c0-1.1-0.9-2-2-2H23z"/><circle class="st0" cx="16" cy="17" r="6" /></g></svg>';
        
        $max_size =  !empty($nc_max_img_size)? $nc_max_img_size: '1024';
        $max_files = !empty($nc_max_img_files)? $nc_max_img_files: '3';
        
        $label = sprintf(esc_html__('Pictures (max size: %s kB, max files: %s)', 'nikstore'), $max_size, $max_files);
        $label2 = '<div class="nikstore-form-media-wrap"><p class="svg_image_upload"><span class="upload-img" >' . $cam_img . '</span>' . esc_html__('Add photos', 'nikstore').'</p><p class="nikstore-comment-media"><span class="nikstore-flex">' . esc_html__('Pictures', 'nikstore').'</span><span class="nikstore-flex">' . esc_html__('max size:', 'nikstore') . $max_size . ' KB</span><span class="nikstore-flex">' . esc_html__('max files:', 'nikstore') . $max_files . '</span></p></div>';
        
        $media_html = '<p class="nikstore-form-media clear-both"><label for="nikstore-comment-media">' . $label . '&nbsp;</label><input type="file" name="ns_image_upload[]" id="nikstore-comment-media" class="ns_image_upload" multiple="" accept=".jpg, .jpeg, .png, .bmp, .gif" /></p>' . $label2;

        if (!NIKSTORE_USER_LOGGED) {
            $comment_form['fields']['nikstore-comment-media'] = $media_html;
        } else {
            $comment_form['comment_field'] .= $media_html;
        }
    
        return $comment_form;
    }
endif;

/**
 * Process comment media
 */
add_filter('preprocess_comment', 'nikstore_preprocess_review_images', 10);
if (!function_exists('nikstore_preprocess_review_images')) :
    function nikstore_preprocess_review_images($commentdata) {
     
     $nc_max_img_size = cs_get_option('comment_img_max_size');
        $nc_max_img_files = cs_get_option('comment_img_max_file');
        
        $files = isset($_FILES['ns_image_upload']) && !empty($_FILES['ns_image_upload']) ? $_FILES['ns_image_upload'] : array();
        
        if (empty($files)) {
            return $commentdata;
        }
        
        $max_size =  !empty($nc_max_img_size)? $nc_max_img_size: '1024';
        $max_files = !empty($nc_max_img_files)? $nc_max_img_files: '3';
        
        /**
         * Allow maxfiles upload
         */
        if (isset($files['name']) && count($files['name']) > $max_files) {
            $mess = sprintf(esc_html__('Maximum number of files allowed is: %s file(s)', 'nikstore'), $max_files);
            wp_die($mess);
        }
        
        /**
         * Allow maxsize upload
         */
        if (isset($files['size']) && !empty($files['size'])) {
            foreach ($files['size'] as $k => $size) {
                if (!$size) {
                    if (isset($files['name'][$k])) {
                        unset($files['name'][$k]);
                    }
                    
                    if (isset($files['type'][$k])) {
                        unset($files['type'][$k]);
                    }
                    
                    if (isset($files['size'][$k])) {
                        unset($files['size'][$k]);
                    }
                    
                    continue;
                }
                
                if ($size > ($max_size * 1024)) {
                    $mess = sprintf(esc_html__('Max size allowed: %s kB', 'nikstore'), $max_size);
                    wp_die($mess);
                }
            }
        }
        
        /**
         * Allow Types upload
         */
        if (isset($files['type']) && !empty($files['type'])) {
            foreach ($files['type'] as $type) {
                $type_file = strtolower($type);
                
                if (!in_array($type_file, array("image/jpg", "image/jpeg", "image/bmp", "image/png", "image/gif"))) {
                    wp_die(esc_html__('Only format accepted: JPG, JPEG, BMP, PNG or GIF', 'nikstore'));
                }
            }
        }
        
        /**
         * Allow upload images
         */
        add_action('comment_post', 'nikstore_add_review_images', 10, 1);
        
        return $commentdata;
    }
endif;

/**
 * Add Review images
 */
if (!function_exists('nikstore_add_review_images')) :
    function nikstore_add_review_images($comment_id) {
        $comment = get_comment($comment_id);
        
        $post_id = isset($comment->comment_post_ID) ? $comment->comment_post_ID : null;
        
        $files  = $_FILES["ns_image_upload"];
        $img_id = array();
        
        if (!empty($files['name'])) {
            require_once ABSPATH . 'wp-admin/includes/image.php';
            require_once ABSPATH . 'wp-admin/includes/file.php';
            require_once ABSPATH . 'wp-admin/includes/media.php';
            
            add_filter('intermediate_image_sizes_advanced', 'nikstore_comment_img_sizes');
            add_filter('big_image_size_threshold', '__return_false');
            
            foreach ($files['name'] as $key => $value) {
                if ($files['size'][$key]) {
                    $file = array(
                        'name'     => apply_filters('nikstore_photo_reviews_image_file_name', $value, $comment_id, $post_id),
                        'type'     => $files['type'][$key],
                        'tmp_name' => $files['tmp_name'][$key],
                        'error'    => $files['error'][$key],
                        'size'     => $files['size'][$key]
                    );

                    $_FILES["upload_file"] = $file;
                    $attachment_id         = media_handle_upload("upload_file", $post_id);

                    if (is_wp_error($attachment_id)) {
                        wp_die($attachment_id->get_error_message());
                    } else {
                        $img_id[] = $attachment_id;
                    }
                }
            }
            
            remove_filter('intermediate_image_sizes_advanced', 'nikstore_comment_img_sizes');
        }

        if (!empty($img_id)) {
            update_comment_meta($comment_id, 'nikstore_review_images', $img_id);
        }
    }
endif;

/**
 * Image size upload for Images review product
 */
if (!function_exists('nikstore_comment_img_sizes')) :
    function nikstore_comment_img_sizes($sizes) {
        if (isset($sizes['thumbnail'])) {
            return array('thumbnail' => $sizes['thumbnail']);
        }

        return $sizes;
    }
endif;

/**
 * Show Review images
 */
add_action('woocommerce_review_after_comment_text', 'nikstore_review_images', 10, 1);
if (!function_exists('nikstore_review_images')) :
    function nikstore_review_images($comment) {
   
        $file = NIKSTORE_CHILD_PATH . '/inc/nikstore-review-images.php';
        include is_file($file) ? $file : NIKSTORE_PATH . '/inc/nikstore-review-images.php';
    }
endif;
