<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined('ABSPATH') || exit;
$page_meta = get_post_meta(get_the_ID(), 'pivoo_page_options', true);

if (class_exists('Nikstore_Core')) {
    if (is_tax('product_cat')) {
        $catmeta = get_term_meta(get_queried_object_id(), 'nikstore_woo_cat_options', true);
        $nikstore_gallery_opt = $catmeta['category_gallery_em'];
        $emcat_gallery_ids = explode(',', $nikstore_gallery_opt);

        $thumb_count = count($emcat_gallery_ids) + 1;

        if ($thumb_count <= 2) {
            $gallery_class = 'slider-no-dot';
        } else {
            $gallery_class = 'slider-with-dot';
        }
    }
}
$hide_breadcrumb = (!empty($page_meta['page_breadcrumb'])) ? $page_meta['page_breadcrumb'] : '';
$page_width = (!empty($page_meta['page_width'])) ? $page_meta['page_width'] : 'container';
$page_b_style = (!empty($page_meta['page_breadcrumb_style'])) ? $page_meta['page_breadcrumb_style'] : '';
if ($page_b_style == 'custom-style') {
    $global_page_icon = (!empty($page_meta['custom_page_icon'])) ? $page_meta['custom_page_icon'] : '';
} else {
    $global_page_icon = cs_get_option('global_page_icon');
}
$desktopcol = cs_get_option('nikstore-archive-col');
$mobcol = cs_get_option('nikstore-archive-col-mob');
$filterpanel = cs_get_option('nikstore-ach-filter-type');
$mobicustomgap = cs_get_option('mob_custom_row_gap');
$filtertext = cs_get_option('nikstore-filter-shortcode');

$archivelayout = cs_get_option('nikstore-archive-type');
$sidebarposition = cs_get_option('archive-sidebar-position');

$title_hide_wd = cs_get_option('x_bd_width_set');
if ($title_hide_wd == true) {
    $containerxpc = 'container nikstore-extended-container';
} else {
    $containerxpc = 'w-100';
}
$customrow_space = "";
if ($mobicustomgap == "on") {
    $customrow_space = "row-mob-smaller";
}
get_header('shop');


/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20 (Removed)
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
do_action('woocommerce_before_main_content');

?>

<section class="<?php echo esc_html($containerxpc); ?>">
    <div class="nikstore-common-breadcrumbs ">
        <?php if (apply_filters('woocommerce_show_page_title', true)) : ?>
            <h1 class="woocommerce-products-header__title page-title"><?php woocommerce_page_title(); ?></h1>
            <?php woocommerce_breadcrumb(); ?>
        <?php endif; ?>

        <?php
        /**
         * Hook: woocommerce_archive_description.
         *
         * @hooked woocommerce_taxonomy_archive_description - 10
         * @hooked woocommerce_product_archive_description - 10
         */
        do_action('woocommerce_archive_description');
        ?>
    </div>
</section>

<section class="nikstore-woo-archive-main">
    <div class="container">


        <?php if ($archivelayout == "sidebar"){ ?>
        <div class="row gx-6">
            <?php } else { ?>
            <div class="without-sidebar">
                <?php } ?>
                <?php if ($archivelayout == "sidebar" && $sidebarposition == "left") { ?>
                    <div class="d-none d-md-block col-12 col-md-3 nikstore-product-archive-sidebar">
                        <?php dynamic_sidebar('nikstore-woo-sidebar'); ?>
                    </div>
                <?php } ?>

                <?php if ($archivelayout == 'sidebar'){ ?>
                <div class="col-12 col-md-9">
                    <?php } else { ?>
                    <div class="w-100">
                        <?php } ?>

                        <?php
                        if (is_tax('product_cat')) {
                            if (!empty($nikstore_gallery_opt)) {
                                ?>
                                <div class="nikstore-woo-cat-carousel carousel <?php echo esc_html($gallery_class); ?>"
                                     data-flickity='{
                                    "cellAlign": "center",
                                    "wrapAround": true,
                                    "autoPlay": false,
                                    "prevNextButtons":false,
                                    "adaptiveHeight": true,
                                    "imagesLoaded": true,
                                    "lazyLoad": 1,
                                    "dragThreshold" : 15,
                                    "pageDots": true,
                                    "rightToLeft": false}'>
                                    <?php
                                    foreach ($emcat_gallery_ids as $em_gallery_id) {
                                        ?>
                                        <div class="nikstore_cat_gallery_slider_item carousel-cell">
                                            <img src="<?php echo wp_get_attachment_url($em_gallery_id); ?>"
                                                 alt="<?php esc_html_e('Product Thumbnail', 'nikstore'); ?>"
                                                 class="carousel-cell-image">
                                        </div>
                                    <?php } ?>
                                </div>
                            <?php }
                        } ?>


                        <div class="row align-items-center">
                            <div class="col-12 col-md-4 pivoo-total-product-count">
                                <?php woocommerce_result_count(); ?>
                            </div>

                            <div class="col-4 col-md-2 nikstore-product-filter-b">

                                <?php if ($archivelayout == "sidebar") { ?>
                                    <div class="d-md-none nikstore-mobile-filter-sidebar">
                                        <button class="nikstore-m-filter-btn" type="button" data-bs-toggle="offcanvas"
                                                data-bs-target="#nikstoreCatCanvas" aria-controls="nikstoreCatCanvas">
                                            <i class="ri-equalizer-line"></i>
                                        </button>

                                        <div class="offcanvas offcanvas-start" tabindex="-1" id="nikstoreCatCanvas"
                                             aria-labelledby="nikstoreCatCanvasLabel">

                                            <div class="offcanvas-body">
                                                <?php dynamic_sidebar('nikstore-woo-sidebar'); ?>
                                            </div>
                                        </div>
                                    </div>
                                <?php } ?>

                                <?php if ($filterpanel == "droppanel") { ?>
                                    <a href="javascript:void(0);" class="nikstore-product-toogle-btn"><i
                                                class="ri-equalizer-line"></i>
                                        <span><?php esc_html_e('Filter', 'nikstore'); ?></span></a>
                                <?php } elseif ($filterpanel == "off-canvas") { ?>
                                    <button class="nikstore-filter-offcanvas-btn" data-bs-toggle="offcanvas"
                                            data-bs-target="#nikstoreproductfilter"
                                            aria-controls="nikstoreproductfilter">
                                        <i class="ri-equalizer-line"></i>
                                        <span><?php esc_html_e('Filter', 'nikstore'); ?></span>
                                    </button>
                                <?php } ?>
                            </div>
                            <div class="col-8 col-md-5 pivoo-product-filter text-md-end">
                                <?php woocommerce_catalog_ordering(); ?>
                            </div>
                            <div class="col-8 col-md-1 text-md-end">
                                <div class="nikstore__product_view_style">
                                    <div class="nav justify-content-end" id="nav-tab" role="tablist">
                                        <a class="me-2 active" id="post-grid-tab" data-bs-toggle="tab" data-bs-target="#post-grid" role="tab" aria-controls="post-grid" aria-selected="true"><i class="fas fa-th-large"></i></a>
                                        <a class="" id="post-list-tab" data-bs-toggle="tab" data-bs-target="#post-list" role="tab" aria-controls="post-list" aria-selected="false"><i class="fas fa-th-list"></i></a>
                                    </div>
                                </div>
                            </div>
                            <?php if ($filterpanel == "droppanel") { ?>
                                <div class="nikstore-filter-toogle-box">
                                    <?php echo do_shortcode($filtertext); ?>
                                </div>
                            <?php } elseif ($filterpanel == "off-canvas") { ?>
                                <div class="nikstore-filter-canvas offcanvas offcanvas-start" tabindex="-1"
                                     id="nikstoreproductfilter" aria-labelledby="nikstoreproductfilterLabel">
                                    <div class="offcanvas-header">
                                        <h5 class="offcanvas-title" id="nikstoreproductfilterLabel">Filter</h5>
                                        <button type="button" class="btn-close text-reset" data-bs-dismiss="offcanvas"
                                                aria-label="Close"></button>
                                    </div>
                                    <div class="offcanvas-body">
                                        <?php echo do_shortcode($filtertext); ?>

                                    </div>
                                </div>
                            <?php } ?>
                            <div class="nikstore__product-view-style-tab-content tab-content" id="myTabContent">
                                <div class="tab-pane fade show active" id="post-grid" role="tabpanel" aria-labelledby="post-grid-tab">
                                    <?php if ($desktopcol){ ?>
                                    <div class="pivoo-shop-product-grid row <?php echo esc_html($customrow_space); ?> row-<?php echo esc_html($mobcol); ?> row-cols-<?php echo esc_html($desktopcol); ?>">
                                        <?php } else { ?>
                                        <div class="pivoo-shop-product-grid row row-cols-1 row-cols-md-3">
                                            <?php } ?>


                                            <?php if (wc_get_loop_prop('total')) {
                                                while (have_posts()) {
                                                    the_post();

                                                    /**
                                                     * Hook: woocommerce_shop_loop.
                                                     */
                                                    do_action('woocommerce_shop_loop');

                                                    wc_get_template_part('content', 'product');
                                                }
                                            }


                                            ?>
                                        </div>
                                    </div>

                                    <div class="tab-pane fade " id="post-list" role="tabpanel" aria-labelledby="post-list-tab">
                                        <?php if ($desktopcol){ ?>
                                        <div class="pivoo-shop-product-grid row <?php echo esc_html($customrow_space); ?> row-cols-1 nikstore__product-view-style-list">
                                            <?php } else { ?>
                                            <div class="pivoo-shop-product-grid row row-cols-1 nikstore__product-view-style-list">
                                                <?php } ?>


                                                <?php if (wc_get_loop_prop('total')) {
                                                    while (have_posts()) {
                                                        the_post();

                                                        /**
                                                         * Hook: woocommerce_shop_loop.
                                                         */
                                                        do_action('woocommerce_shop_loop');

                                                        wc_get_template_part('content', 'product-list');
                                                    }
                                                }


                                                ?>
                                            </div>
                                        </div>
                                    </div>

                                </div><!---Tab End -->

                                <?php
                                /**
                                 * Hook: woocommerce_after_shop_loop.
                                 *
                                 * @hooked woocommerce_pagination - 10
                                 */
                                do_action('woocommerce_after_shop_loop');

                                ?>


                                <?php if ($archivelayout == "sidebar" && $sidebarposition == "right") { ?>
                                    <div class="col-12 d-none d-md-block col-md-3 nikstore-product-archive-sidebar">
                                        <?php dynamic_sidebar('nikstore-woo-sidebar'); ?>
                                    </div>
                                <?php } ?>
                            </div>


                        </div>

</section>

<?php
/**
 * Hook: woocommerce_after_main_content.
 *
 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
 */
do_action('woocommerce_after_main_content');

?>
<?php

get_footer('shop');

?>
